package com.agri.system.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.agri.system.domain.SysAgriAlarmRelation;

/**
 * 告警方式设置Mapper接口
 * 
 * @author agri
 * @date 2026-01-08
 */
public interface SysAgriAlarmRelationMapper extends BaseMapper<SysAgriAlarmRelation>
{
    /**
     * 查询告警方式设置
     * 
     * @param id 告警方式设置主键
     * @return 告警方式设置
     */
    public SysAgriAlarmRelation selectSysAgriAlarmRelationById(Long id);

    /**
     * 查询告警方式设置列表
     * 
     * @param sysAgriAlarmRelation 告警方式设置
     * @return 告警方式设置集合
     */
    public List<SysAgriAlarmRelation> selectSysAgriAlarmRelationList(SysAgriAlarmRelation sysAgriAlarmRelation);

    /**
     * 新增告警方式设置
     * 
     * @param sysAgriAlarmRelation 告警方式设置
     * @return 结果
     */
    public int insertSysAgriAlarmRelation(SysAgriAlarmRelation sysAgriAlarmRelation);

    /**
     * 修改告警方式设置
     * 
     * @param sysAgriAlarmRelation 告警方式设置
     * @return 结果
     */
    public int updateSysAgriAlarmRelation(SysAgriAlarmRelation sysAgriAlarmRelation);

    /**
     * 删除告警方式设置
     * 
     * @param id 告警方式设置主键
     * @return 结果
     */
    public int deleteSysAgriAlarmRelationById(Long id);

    /**
     * 批量删除告警方式设置
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysAgriAlarmRelationByIds(Long[] ids);
}
